summaryrefslogtreecommitdiff
path: root/platform/macos/config.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'platform/macos/config.cmake')
-rw-r--r--platform/macos/config.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/platform/macos/config.cmake b/platform/macos/config.cmake
index e49a54f5eb..bc3de392dd 100644
--- a/platform/macos/config.cmake
+++ b/platform/macos/config.cmake
@@ -1,7 +1,7 @@
include(cmake/loop-darwin.cmake)
macro(mbgl_platform_core)
- target_sources_from_file(mbgl-core PRIVATE platform/macos/core-files.txt)
+ target_sources_from_file(mbgl-core PRIVATE platform/macos/core-files.json)
if(WITH_EGL)
target_sources(mbgl-core
@@ -39,8 +39,8 @@ endmacro()
macro(mbgl_filesource)
- # Modify platform/darwin/filesource-files.txt to change the source files for this target.
- target_sources_from_file(mbgl-filesource PRIVATE platform/darwin/filesource-files.txt)
+ # Modify platform/darwin/filesource-files.json to change the source files for this target.
+ target_sources_from_file(mbgl-filesource PRIVATE platform/darwin/filesource-files.json)
target_compile_options(mbgl-filesource
PRIVATE -fobjc-arc